#!/bin/sh

#~ # cat /tmp/o
#~ # zysync --query_remote "192.168.1.9" admin 1234 "fgwe1/admin" 2 > /tmp/o
#~ # cat /tmp/o
#Format:
#        > zysync --query_remote IP USER PWD REMOTE_PATH
#        ~ # zysync --query_remote "192.168.1.9" admin 1234 "fgwe1/admin" 2>/tmp/o
#        ~ # cat /tmp/o
#        @ERROR: Unknown module 'fgwe1'
#        rsync error: error starting client-server protocol (code 5) at main.c(1561) [receiver=3.0.0]

LOG_FILE="/i-data/.system/BackupPlanner.log"
ZYSYNC="/usr/local/zy-pkgs/bin/zysync"
ZYSYNC_QUERY_REMOTE="${ZYSYNC} --query_remote"
BACKUP_DB="/etc/zyxel/backupjob.db"
SQL_GET_ALL_SYNC_REMOTE_JOBS="select * from BackupJobEntry where (BackupMethod='3' OR BackupMethod='4') AND BackupTarget='1';"
SQL_RESULT="/tmp/sql_result"
QUERY_ERR_MSG="/tmp/err_msg"
QUERY_RESULT_MSG="/tmp/mod_lst"


get_remote_module_contents()
{
	# error code:
	#	- 0: get module contents succefully.
	#	- 1: no enough arguments to get remote module contents.
	#	- 2: @ERROR: Unknown module
	#	- 3: wrong argument format for query_remote
	#	- 4: other rsync errors
	#	- 5: No such file or directory
	#
	# module contents will be recorded in "/tmp/mod_lst"
	# error message will be recorded in "/tmp/err_msg"
	if [ "$#" != "4" ]; then
		echo "no enough arguments to get remote module contents." > /tmp/err_msg
		return 1
	fi
	
	${ZYSYNC_QUERY_REMOTE} "$1" "$2" "$3" "$4" 2>${QUERY_ERR_MSG} 1>${QUERY_RESULT_MSG}
	grep "^@ERROR: Unknown module" ${QUERY_ERR_MSG} > /dev/null
	if [ "$?" = "0" ]; then
		return 2
	fi
	
	grep "^Format:" ${QUERY_RESULT_MSG} > /dev/null
	if [ "$?" = "0" ]; then
		return 3
	fi
	
	grep "^rsync error:" ${QUERY_ERR_MSG} > /dev/null
	if [ "$?" = "0" ]; then
		return 4
	fi
	
	grep "No such file or directory" ${QUERY_ERR_MSG} > /dev/null
	if [ "$?" = "0" ]; then
		return 5
	fi
	
	return 0	
}


# main start
# remote server info
JOBNAME=""
R_IP=""
R_ACCOUNT=""
R_PASSWORD=""
R_PATH=""

GOT_AVAILABLE_MODULE=0


sqlite3 "${BACKUP_DB}" "${SQL_GET_ALL_SYNC_REMOTE_JOBS}" > ${SQL_RESULT}
while read db_line; do		# get a sync remote job from backup db
	echo $db_line
	JOBNAME="`echo $db_line | awk -F'|' '{print $1}'`"
	R_IP="`echo $db_line | awk -F'|' '{print $6}'`"
	R_ACCOUNT="`echo $db_line | awk -F'|' '{print $7}'`"
	R_PASSWORD="`echo $db_line | awk -F'|' '{print $8}'`"
	R_PATH="`echo $db_line | awk -F'|' '{print $11}'`"

	echo "JOBNAME: ${JOBNAME}"
	echo "R_IP: ${R_IP}"
	echo "R_ACCOUNT: ${R_ACCOUNT}"
	echo "R_PASSWORD: ${R_PASSWORD}"
	echo "R_PATH: ${R_PATH}"
	
	GOT_AVAILABLE_MODULE=0

	get_remote_module_contents "${R_IP}" "${R_ACCOUNT}" "${R_PASSWORD}" "${R_PATH}"
	if [ "$?" = "0" ]; then
		echo "module \"${R_PATH}\" exists for job \"${JOBNAME}\"."
		GOT_AVAILABLE_MODULE=1
	else
		echo "module \"${R_PATH}\" didn't exist"
		
		# get root modules from remote target
		get_remote_module_contents "${R_IP}" "${R_ACCOUNT}" "${R_PASSWORD}" ""
		mv ${QUERY_RESULT_MSG} ${QUERY_RESULT_MSG}.bak		# avoid the following "get_remote_module_contents" changes it's contents
		while read module_line; do
			echo "---> try \"${module_line}/${R_PATH}\" ..."
			get_remote_module_contents "${R_IP}" "${R_ACCOUNT}" "${R_PASSWORD}" "${module_line}/${R_PATH}"
			if [ "$?" = "0" ]; then
				echo "---> get available module \"${module_line}/${R_PATH}\" for job \"${JOBNAME}\"."
				GOT_AVAILABLE_MODULE=1

				sqlite3 "${BACKUP_DB}" "update BackupJobEntry set TargetPath='${module_line}/${R_PATH}' where Jobname='${JOBNAME}'"
				break
			fi

			VOL_CHANGED_PATH="${module_line}/`echo "${R_PATH}" | cut -d '/' -f 2-`"
			echo "---> try \"${VOL_CHANGED_PATH}\" ..."
			get_remote_module_contents "${R_IP}" "${R_ACCOUNT}" "${R_PASSWORD}" "${VOL_CHANGED_PATH}"
			if [ "$?" = "0" ]; then
				echo "---> get available module \"${VOL_CHANGED_PATH}\" for job \"${JOBNAME}\"."
				GOT_AVAILABLE_MODULE=1

				sqlite3 "${BACKUP_DB}" "update BackupJobEntry set TargetPath='${VOL_CHANGED_PATH}' where Jobname='${JOBNAME}'"
				break
			fi
		done < ${QUERY_RESULT_MSG}.bak
	fi

	if [ ${GOT_AVAILABLE_MODULE} -eq 0 ]; then
		echo "No available module for job \"${JOBNAME}\""
	fi
	
done < ${SQL_RESULT}