#/bin/sh

###########################################################################################
# variable definition
PKG_CONFIG_PATH="/etc/zyxel/zy-pkgs/BackupPlanner/"
STUNNELC_PID_FILE="/var/run/stunnelc.pid"
STUNNELC_CONF_FILE=$PKG_CONFIG_PATH"stunnel/stunnelc.conf"
#STUNNELC_LOG_FILE="/var/log/stunnelc.log"
if [ -d /i-data/.system ]; then
	STUNNELC_LOG_FILE="/i-data/.system/stunnelc.log"
else
	STUNNELC_LOG_FILE="/i-data/.zyxel/stunnelc.log"
fi

STUNNEL_CONF_FOLDER=$PKG_CONFIG_PATH"stunnel"

STUNNELC_ACPT_PORT="2345"
STUNNELC_CONT_PORT="9527"


CERT_FILE=$PKG_CONFIG_PATH"zysync/zysync.cert"
KEY_FILE=$PKG_CONFIG_PATH"zysync/zysync.key"

SSL_VER="TLSv1"		# Protocol version (all, SSLv2, SSLv3, TLSv1)
DEBUG_LEVEL="7"

if [ "${1}" = "" ]; then
	echo "please give the remote ip:"
	echo "Ex. ${0} 172.23.26.245"
	exit 1
fi

REMOTE_IP="${1}:"


###########################################################################################
# main start
if [ -f ${STUNNELC_PID_FILE} ]; then
	echo "===> stunnel client(`cat ${STUNNELC_PID_FILE}`) exists, please stop it first."
	exit 1
fi

## - must stop zysync server first!
#if [ -f ${ZYSYNCD_PID_FILE} ]; then
#	stop_zysync_server.sh
#	sleep 3
#fi

if [ ! -d ${STUNNEL_CONF_FOLDER} ] ; then
	echo "===> Creating \"${STUNNEL_CONF_FOLDER}\" folder ..."
	mkdir -p ${STUNNEL_CONF_FOLDER}
fi

echo "===> Generating stunnel client config file ..."
echo "########## This file is generated by start_stunnel_client.sh ##########"	>  ${STUNNELC_CONF_FILE}
echo "cert = ${CERT_FILE}"							>> ${STUNNELC_CONF_FILE}
echo "key = ${KEY_FILE}"							>> ${STUNNELC_CONF_FILE}
echo "sslVersion = ${SSL_VER}"							>> ${STUNNELC_CONF_FILE}
echo 										>> ${STUNNELC_CONF_FILE}
echo "client = yes"								>> ${STUNNELC_CONF_FILE}
echo "pid = ${STUNNELC_PID_FILE}"						>> ${STUNNELC_CONF_FILE}
echo 										>> ${STUNNELC_CONF_FILE}
echo "debug = ${DEBUG_LEVEL}"							>> ${STUNNELC_CONF_FILE}
echo "output = ${STUNNELC_LOG_FILE}"						>> ${STUNNELC_CONF_FILE}
echo 										>> ${STUNNELC_CONF_FILE}
echo "[szysync]"								>> ${STUNNELC_CONF_FILE}
echo "accept = ${STUNNELC_ACPT_PORT}"						>> ${STUNNELC_CONF_FILE}
echo "connect = ${REMOTE_IP}${STUNNELC_CONT_PORT}"				>> ${STUNNELC_CONF_FILE}


echo "===> Starting stunnel server ..."
/usr/local/zy-pkgs/bin/stunnel ${STUNNELC_CONF_FILE}

echo "Done"
